<?php
/**
 * Class de gestion de chargement des fichier YAML.
 * 
 * @author ulrich, 26/06/09
 * @package ulMyConfigHandlerPlugin
 */
class clsYaml
{

	/**
	 * Fonction qui charge un fihcier YML. Si le ficher est configuré dans un fichier config_handler.yml il le prend du cache sinon il parse
	 * le fichier avec la class sfYaml et Spyc
	 * 
	 * @author ulrich, 26/06/09
	 * @author ulrich, 30/06/09 -> regroupe les 2 paramètre en un seul.
	 * @author ulrich, 07/09/10 -> prise en charge des chemins des plugins.
	 * @param  String $psCheminEtFichier: nom du fichier et son chemin complet.
	 * @return Array: parsing du fichier YML 
	 */
	public static function chargerYaml($psCheminEtFichier)
	{	
		$aYaml = self::chargerYamlWithCache($psCheminEtFichier);
		
		if(!$aYaml)
		{
			if(preg_match('#^/?(plugins/(\w+/)+\w+)\.yml$#', $psCheminEtFichier))
			{
				$sNomVar = sfConfig::get('sf_root_dir').DIRECTORY_SEPARATOR;
				$sNomVar .= preg_replace('#^/?(plugins/(\w+/)+\w+\.yml)$#', "$1", $psCheminEtFichier);
				$aYaml = self::chargerYamlWithoutCache($sNomVar);
			}
			else
			{
				$aYaml = self::chargerYamlWithoutCache(sfConfig::get('sf_app_dir').DIRECTORY_SEPARATOR.$psCheminEtFichier);
			}
		}
		
		return $aYaml;
	}
	
	/**
	 * Fonction qui charge un fichier YML depuis le cache. 
	 * Retounr false si le fichier n'est pas configuré dans un config_handler.yml  
	 * Retounr false si le nom de la variable n'est pas identique au nom du fichier sans son extension.
	 * 	 
	 * @author ulrich, 26/06/09
	 * @author ulrich, 30/06/09 -> regroupe les 2 paramètre en un seul.
	 * @author ulrich, 30/06/09 -> fix bug dans l'expression régulière
	 * @author ulrich, 08/12/10 => compatibilité sf1.4
	 * @param  String $psCheminEtFichier: nom du fichier et son chemin complet.
	 * @return Array: parsing du fichier YML 
	 */
	public static function chargerYamlWithCache($psCheminEtFichier)
	{
		try
		{			
			$oConfigCache = new sfConfigCache(sfContext::getInstance()->getConfiguration());
			include($oConfigCache->checkConfig($psCheminEtFichier));
		}
		catch(Exception $e)
		{
			return false;
		}

		//bullshit en prod, raz le bol de symfo 1.0
		//pas vérifié en 1.4
		$sNomVar1 = sfConfig::get('sf_root_dir').DIRECTORY_SEPARATOR;
		$sNomVar1 .= preg_replace('#^/?(plugins/(\w+/)+\w+\.yml)$#', "$1", $psCheminEtFichier);
		$sNomVar = preg_replace("/^(\/)?(\w+\/)+(\w+)\.yml$/", "$3", $psCheminEtFichier);
		
		if(sfConfig::has($sNomVar))
		{
			return sfConfig::get($sNomVar);
		}
		elseif(sfConfig::has($sNomVar1))
		{
			return sfConfig::get($sNomVar1);
		}
		else
		{
			return false;
		}		
	}
	
	/**
	 * Fonction qui charge un fichier YML en le parsant avec les classe sfYaml et Spyc. 
	 * 	 
	 * @author ulrich, 26/06/09
	 * @author ulrich, 30/06/09 -> ajoute controle si le fichier Existe
	 * @author ulrich, 09/12/10 -> suppression du chargement manuel de sfYaml, thanks 1.4
	 * @param  String $psCheminEtFichier: nom du fichier et son chemin complet.
	 * @return Array: parsing du fichier YML 
	 */
	public static function chargerYamlWithoutCache($psCheminEtFichier)
	{
		
		if(file_exists($psCheminEtFichier))
		{  
			$aYaml = sfYaml::load($psCheminEtFichier);
			return $aYaml;
		}
		else
		{
			throw new ulMyConfigHandlerPluginException('clsYaml::chargerYamlWithoutCache() => file unfound at this address:'.$psCheminEtFichier);
		}
	}	
}